From 0ee21d97ac9cf8e55d0663714e3f13927670f6be Mon Sep 17 00:00:00 2001
From: qq_41295110 <qq_41295110@noreply.gitcode.com>
Date: 星期二, 29 七月 2025 15:08:11 +0800
Subject: [PATCH] 修改扫码功能

---
 pages/qitarukujiaoyan/form.vue           |   60 
 pages/shouliaotongzhi/table.vue          |   19 
 pages/tiaomachaima/tiaomachaima.vue      |   67 +
 pages/qitaruku/form.vue                  |   26 
 pages/baoyangjilu/form.vue               |   60 
 pages/shebeiweixiu/form.vue              |   60 
 .hbuilderx/launch.json                   |    1 
 pages/xiaoshouchuku/form.vue             |   28 
 pages/shengchanlingliao/form.vue         |   28 
 pages/xiaoshoutuihuo/form.vue            |   46 
 pages/caigourukujiaoyan/form.vue         |   60 
 pages/xiaoshouchukujiaoyan/form.vue      |   58 
 pages/baoyangjihua/form.vue              |   60 
 pages/shebeiguanli/form.vue              |   62 
 pages/weiwaigxIn/form.vue                |  110 ++
 pages/weiwailingliao/form.vue            |   26 
 pages/shengchandiaobo/form.vue           |   18 
 pages/qitachuku/form.vue                 |   26 
 pages/guzhangdengji/form.vue             |   60 
 pages/tiaomadaying/tiaomadaying.vue      |   81 +-
 pages/caigouruku/form.vue                |   28 
 pages/shengchanbuliao/form.vue           |   26 
 pages/shengchanlingliaoshengdan/form.vue |   26 
 pages/shebeidangan/form.vue              |   62 
 pages/weiwaigxOut/form.vue               |  106 ++
 pages/shengchanrukushengdan/form.vue     |   26 
 pages/wuliaosaoma/wuliaosaoma.vue        |   87 +-
 pages/MJGL/shangmudan/form.vue           |   18 
 pages/qitaruku_v2/form.vue               |   26 
 pages/caigoutuiliao/form.vue             |   28 
 pages/gongxuIn/form.vue                  |   56 
 pages/shengchanruku/form.vue             |   18 
 pages/qitachuku_v2/form.vue              |   26 
 pages/qitachukujiaoyan/detail.vue        |   60 
 pages/weiwailingliaojiaoyan/form.vue     |   60 
 manifest.json                            |   42 +
 pages/shengchanbuliaojiaoyan/form.vue    |   56 
 pages/weiwaigxOut/firstCheck.vue         |   62 
 pages/gongxuOut/form.vue                 |  129 ++
 pages/weiwaibuliaojiaoyan/form.vue       |   60 
 pages/caigoudingdan/caigoudingdan.vue    |   19 
 41 files changed, 1,141 insertions(+), 836 deletions(-)

diff --git a/.hbuilderx/launch.json b/.hbuilderx/launch.json
index b4d909b..91f5ad9 100644
--- a/.hbuilderx/launch.json
+++ b/.hbuilderx/launch.json
@@ -22,6 +22,7 @@
         },
         {
             "openVueDevtools" : true,
+            "playground" : "custom",
             "type" : "uni-app:app-android"
         }
     ]
diff --git a/manifest.json b/manifest.json
index e60c2bc..89816a9 100644
--- a/manifest.json
+++ b/manifest.json
@@ -2,8 +2,8 @@
     "name" : "鏅轰簯LMES",
     "appid" : "__UNI__B002F49",
     "description" : "",
-    "versionName" : "1.0.25",
-    "versionCode" : 125,
+    "versionName" : "1.0.28",
+    "versionCode" : 128,
     "transformPx" : false,
     /* 5+App鐗规湁鐩稿叧 */
     "app-plus" : {
@@ -46,7 +46,8 @@
                     "<uses-permission android:name=\"android.permission.WRITE_CONTACTS\"/>",
                     "<uses-permission android:name=\"android.permission.WRITE_SETTINGS\"/>"
                 ],
-                "abiFilters" : [ "armeabi-v7a", "arm64-v8a", "x86" ]
+                "abiFilters" : [ "armeabi-v7a", "arm64-v8a", "x86" ],
+                "minSdkVersion" : 23
             },
             /* ios鎵撳寘閰嶇疆 */
             "ios" : {
@@ -88,6 +89,41 @@
                     }
                 }
             }
+        },
+        "nativePlugins" : {
+            "Mpaas-Scan" : {
+                "AppId" : "ALIPUB2087527291109",
+                "License" : "uqSDoPf8ArVz0mKgs62fihEiELxaNc/fCwZU2eRwDvfdN3uhWCRRtXgszPkWmqjSUPYSFgOdMh0dv4UkQe0twC8fZt8+71FB3K6A83NaLtwi5gu+hVJ8MZnOTUe/ipmCCVmRGapmwfKfyHbV2oSAOLbq4/fgBszewOVtdjx7ogzyIltcCHOESsdejnFxmg/7+HuX5/0qmLxGIUUwGhwQazot0bQeGBP8sJ4ONZLd7n4WQFe8bQCrRcB3CPAFClwA/VldpIjOwrTYTd0LHyrhPJN5xHdpeoKmGIyJYsoxm94DDUFZyGHB+Qs+3euCJHOlCqpa7/A+ciAdUSeKHa0tkw==",
+                "WorkspaceId" : "default",
+                "__plugin_info__" : {
+                    "name" : "鏀粯瀹濆師鐢熸壂鐮佹彃浠�",
+                    "description" : "鏀粯瀹濆師鐢熸壂鐮佺粍浠讹紝鍖呬綋绉粎0.7MB锛�15鍒嗛挓鍗冲彲瀹屾垚鎺ュ叆銆傚悓鏃讹紝mPaaS鎻愪緵銆屾壂鐮佸垎鏋愩�嶅ぇ鐩�",
+                    "platforms" : "Android,iOS",
+                    "url" : "https://ext.dcloud.net.cn/plugin?id=2636",
+                    "android_package_name" : "com.shebeiguanli.www",
+                    "ios_bundle_id" : "",
+                    "isCloud" : true,
+                    "bought" : 1,
+                    "pid" : "2636",
+                    "parameters" : {
+                        "AppId" : {
+                            "des" : "Android骞冲彴鐨凙ppId锛岃濉啓Android鐨刢onfig鏂囦欢涓殑appId瀵瑰簲鐨勫��",
+                            "key" : "mobilegw.appid",
+                            "value" : ""
+                        },
+                        "License" : {
+                            "des" : "Android骞冲彴鐨凩icense,锛岃濉啓Android鐨刢onfig鏂囦欢涓殑mpaasConfigLicense瀵瑰簲鐨勫��",
+                            "key" : "mpaasConfigLicense",
+                            "value" : ""
+                        },
+                        "WorkspaceId" : {
+                            "des" : "Android骞冲彴鐨刉orkspaceId锛岃濉啓Android鐨刢onfig鏂囦欢涓殑workspaceId瀵瑰簲鐨勫��",
+                            "key" : "workspaceId",
+                            "value" : ""
+                        }
+                    }
+                }
+            }
         }
     },
     /* 蹇簲鐢ㄧ壒鏈夌浉鍏� */
diff --git a/pages/MJGL/shangmudan/form.vue b/pages/MJGL/shangmudan/form.vue
index 8ae3262..8a02218 100644
--- a/pages/MJGL/shangmudan/form.vue
+++ b/pages/MJGL/shangmudan/form.vue
@@ -248,14 +248,16 @@
         methods: {
 			//鎵爜
 			toScanCode(){		
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						this.hform.HBarCode = res.result
-						this.getHBarCodeData(res.result)
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					this.hform.HBarCode = ret.resp_result
+					this.getHBarCodeData(ret.resp_result)
+				})
 			},
 			//鏃ユ湡
 			HDateChange(e){
diff --git a/pages/baoyangjihua/form.vue b/pages/baoyangjihua/form.vue
index 21971cc..7a8fe97 100644
--- a/pages/baoyangjihua/form.vue
+++ b/pages/baoyangjihua/form.vue
@@ -244,35 +244,37 @@
 			},
 			//鎵爜閫夋嫨璁惧
 			toScanCode(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						uni.request({
-						    url: this.serverUrl + '/Gy_EquipFileMain/Gy_MouldFileBillBarCodeInfo', 
-							data: { HBarCode: res.result },
-						    success: (res) => {
-						        console.log(res.data);
-								if(res.data.count == 1){
-									var data = res.data.list[0][0]
-									this.hform.HEquipID = data.hmainid
-									this.hform.HEquipName = data.璁惧鍚嶇О
-								}
-								uni.showToast({
-									title:res.data.Message,
-									icon:'none'
-								})
-							},
-							fail: (res) => {
-								console.log(res);
-								uni.showToast({
-									title:'鎺ュ彛璇锋眰澶辫触',
-									icon:'none'
-								})
-							},
-						});
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					uni.request({
+					    url: this.serverUrl + '/Gy_EquipFileMain/Gy_MouldFileBillBarCodeInfo', 
+						data: { HBarCode: ret.resp_result },
+					    success: (res) => {
+					        console.log(res.data);
+							if(res.data.count == 1){
+								var data = res.data.list[0][0]
+								this.hform.HEquipID = data.hmainid
+								this.hform.HEquipName = data.璁惧鍚嶇О
+							}
+							uni.showToast({
+								title:res.data.Message,
+								icon:'none'
+							})
+						},
+						fail: (res) => {
+							console.log(res);
+							uni.showToast({
+								title:'鎺ュ彛璇锋眰澶辫触',
+								icon:'none'
+							})
+						},
+					});
+				})
 			},
 			
 			//鑾峰彇璁惧淇濆吇瑙勭▼鏁版嵁
diff --git a/pages/baoyangjilu/form.vue b/pages/baoyangjilu/form.vue
index 4cf6882..e7ce9e0 100644
--- a/pages/baoyangjilu/form.vue
+++ b/pages/baoyangjilu/form.vue
@@ -156,35 +156,37 @@
         methods: {
 			//鎵爜
 			toScanCode(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						uni.request({
-						    url: this.serverUrl + '/Gy_EquipFileMain/Gy_MouldFileBillBarCodeInfo', 
-							data: { HBarCode: res.result },
-						    success: (res) => {
-						        console.log(res.data);
-								if(res.data.count == 1){
-									var data = res.data.list[0][0]
-									this.hform.HEquipID = data.hmainid
-									this.hform.HEquipName = data.璁惧鍚嶇О
-								}
-								uni.showToast({
-									title:res.data.Message,
-									icon:'none'
-								})
-							},
-							fail: (res) => {
-								console.log(res);
-								uni.showToast({
-									title:'鎺ュ彛璇锋眰澶辫触',
-									icon:'none'
-								})
-							},
-						});
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					uni.request({
+					    url: this.serverUrl + '/Gy_EquipFileMain/Gy_MouldFileBillBarCodeInfo', 
+						data: { HBarCode: ret.resp_result },
+					    success: (res) => {
+					        console.log(res.data);
+							if(res.data.count == 1){
+								var data = res.data.list[0][0]
+								this.hform.HEquipID = data.hmainid
+								this.hform.HEquipName = data.璁惧鍚嶇О
+							}
+							uni.showToast({
+								title:res.data.Message,
+								icon:'none'
+							})
+						},
+						fail: (res) => {
+							console.log(res);
+							uni.showToast({
+								title:'鎺ュ彛璇锋眰澶辫触',
+								icon:'none'
+							})
+						},
+					});
+				})
 			},
 			upCode(){
 				uni.request({
diff --git a/pages/caigoudingdan/caigoudingdan.vue b/pages/caigoudingdan/caigoudingdan.vue
index 4d8c0f0..21ecc55 100644
--- a/pages/caigoudingdan/caigoudingdan.vue
+++ b/pages/caigoudingdan/caigoudingdan.vue
@@ -81,15 +81,16 @@
 		methods: {
 			//鎵爜
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						this.HBarCode = res.result
-
-						this.getCode(this.HBarCode)
-					}
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					this.HBarCode = ret.resp_result
+					this.getCode(this.HBarCode)
+				})
 			},
 			//鎵潯鐮佸鐞�
 			getCode(HBarCode) {
diff --git a/pages/caigouruku/form.vue b/pages/caigouruku/form.vue
index c53a42a..72ae5c1 100644
--- a/pages/caigouruku/form.vue
+++ b/pages/caigouruku/form.vue
@@ -324,19 +324,21 @@
 			},
 			//鎵爜
 			toScanCode(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						if(this.hform.HBarCode == '*'){
-							this.hform.HBarCode = this.hform.HBarCode + res.result
-						}else{
-							this.hform.HBarCode = res.result
-						}
-						
-						this.getCode(this.hform.HBarCode)
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					if(this.hform.HBarCode == '*'){
+						this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					}else{
+						this.hform.HBarCode = ret.resp_result
+					}
+					
+					this.getCode(this.hform.HBarCode)
+				})
 			},
 			//鎵叾浠�(浠撳簱锛屼粨浣�)
 			// toScanData(e){
diff --git a/pages/caigourukujiaoyan/form.vue b/pages/caigourukujiaoyan/form.vue
index 198def9..2f961a4 100644
--- a/pages/caigourukujiaoyan/form.vue
+++ b/pages/caigourukujiaoyan/form.vue
@@ -253,36 +253,40 @@
 		methods: {
 			//鎵爜
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						// if(this.hform.HBarCode == '*'){
-						// 	this.hform.HBarCode = this.hform.HBarCode + res.result
-						// }else{
-						// 	this.hform.HBarCode = res.result
-						// }
-						this.hform.HBarCode = res.result
-						// this.GetMeesageByBillNo(this.hform.HBarCode)
-						this.getCode(this.hform.HBarCode)
-					}
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					// if(this.hform.HBarCode == '*'){
+					// 	this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					// }else{
+					// 	this.hform.HBarCode = ret.resp_result
+					// }
+					this.hform.HBarCode = ret.resp_result
+					// this.GetMeesageByBillNo(this.hform.HBarCode)
+					this.getCode(this.hform.HBarCode)
+				})
+			
 			},
 			toScanBillCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						// if(this.hform.HBarCode == '*'){
-						// 	this.hform.HBarCode = this.hform.HBarCode + res.result
-						// }else{
-						// 	this.hform.HBarCode = res.result
-						// }
-						
-						this.hform.HBillNo = res.result
-						this.GetMeesageByBillNo(this.hform.HBillNo)
-					}
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					// if(this.hform.HBarCode == '*'){
+					// 	this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					// }else{
+					// 	this.hform.HBarCode = ret.resp_result
+					// }
+					this.hform.HBillNo = ret.resp_result
+					this.GetMeesageByBillNo(this.hform.HBillNo)
+				})
 			},
 			//鎵弿鍗曟嵁鍙锋潯鐮�
 			GetMeesageByBillNo(e) {
diff --git a/pages/caigoutuiliao/form.vue b/pages/caigoutuiliao/form.vue
index 5da72e7..6800c1f 100644
--- a/pages/caigoutuiliao/form.vue
+++ b/pages/caigoutuiliao/form.vue
@@ -324,19 +324,21 @@
 			},
 			//鎵爜
 			toScanCode(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						if(this.hform.HBarCode == '*'){
-							this.hform.HBarCode = this.hform.HBarCode + res.result
-						}else{
-							this.hform.HBarCode = res.result
-						}
-						
-						this.getCode(this.hform.HBarCode)
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					if(this.hform.HBarCode == '*'){
+						this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					}else{
+						this.hform.HBarCode = ret.resp_result
+					}
+					
+					this.getCode(this.hform.HBarCode)
+				})
 			},
 			//鎵叾浠�(浠撳簱锛屼粨浣�)
 			// toScanData(e){
diff --git a/pages/gongxuIn/form.vue b/pages/gongxuIn/form.vue
index 2ba6c79..05ff13b 100644
--- a/pages/gongxuIn/form.vue
+++ b/pages/gongxuIn/form.vue
@@ -347,34 +347,35 @@
         methods: {
 			//鎵爜
 			toScanCode(e){
-				// this.hform.HBarCode = 'GXLX250603001-01'
-				// this.getHBarCodeData('GXLX250603001-01')
-				
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						if(e==0){
-							this.hform.HBarCode = res.result
-							this.getHBarCodeData(res.result)
-						}else{
-							this.hform.HBarCode_Mater = res.result
-							this.getHBarCodeMater(res.result)
-						}
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					if(e==0){
+						this.hform.HBarCode = ret.resp_result
+						this.getHBarCodeData(ret.resp_result)
+					}else{
+						this.hform.HBarCode_Mater = ret.resp_result
+						this.getHBarCodeMater(ret.resp_result)
+					}
+				})
 			},
 			//鎵祦姘村彿
 			toScanProcNo(){
 				if(this.hform.HProcExchHinteID){
-					uni.scanCode({
-					    onlyFromCamera: true,
-					    success: (res) => {
-					        console.log('鏉$爜鍐呭锛�' + res.result);
-							this.hform.HProcNo = res.result
-							this.getHProcNoData(this.hform.HBarCode,res.result)
-					    }
-					});
+					var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+					mpaasScanModule.mpaasScan({
+						'hideAlbum': true,
+						'timeoutInterval':'10', //瓒呮椂鏃堕棿
+						'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+					},(ret) => {
+						console.log(ret.resp_result)
+						this.hform.HProcNo = resp_result
+						this.getHProcNoData(this.hform.HBarCode,resp_result)
+					})
 				}else{
 					uni.showToast({
 						title:'璇锋壂瀹屾祦杞崱鍚庡啀鎵厤浠剁爜',
@@ -952,7 +953,12 @@
 									    }
 									});
 								}
-            				}
+            				}else{
+								uni.showToast({
+									title:res.data.Message,
+									icon:'none'
+								})
+							}
 
             			},
             			fail: (res) => {
diff --git a/pages/gongxuOut/form.vue b/pages/gongxuOut/form.vue
index 4808f56..d234022 100644
--- a/pages/gongxuOut/form.vue
+++ b/pages/gongxuOut/form.vue
@@ -560,29 +560,87 @@
 			this.getHGroupList()
 			this.getHEmpList()
 			this.getHCenterList()
+			
+			this.getDefValByUser()
 		},
         methods: {
+			//閫氳繃鐧诲綍鐢ㄦ埛鑾峰彇榛樿鍊�
+			getDefValByUser(){
+				uni.request({
+				    url: this.serverUrl + '/Cj_StationInBill/GetDefValByUser', 
+					type: "GET",
+					async: false,
+					data: { "Czybm": this.userInfo.Czybm, "Czymc":  this.userInfo.Czymc },
+				    success: (res) => {
+						// console.log(res.data)
+						if(res.data.count == 1){
+							var data = res.data.data[0]
+							this.hform.HGroupID = data.HGroupID
+							this.hform.HGroupName = data.鐢熶骇鐝粍鍚嶇О
+							this.hform.HEmpID = data.HEmpID
+							this.hform.HEmpName = data.鎿嶄綔鍛樺悕绉�
+							this.hform.HEmpNumber = data.鎿嶄綔鍛樹唬鐮�
+							this.hform.HSourceID = data.HSourceID
+							this.hform.HSourceName = data.鐢熶骇璧勬簮鍚嶇О
+							this.hform.HCenterID = data.HWorkCenterID
+							this.hform.HCenterName = data.宸ヤ綔涓績鍚嶇О
+							this.hform.HEmpName_second = data.鎿嶄綔鍛樺悕绉�
+						}else{
+							uni.showToast({
+								title:'鑾峰彇鐢熶骇鐝粍淇℃伅澶辫触',
+								icon:'none'
+							})
+						}
+					},
+					fail: (res) => {
+						console.log(res);
+						uni.showToast({
+							title:'鑾峰彇鐢熶骇鐝粍淇℃伅澶辫触',
+							icon:'none'
+						})
+					},
+				});
+			},
 			//鎵爜
 			toScanCode(){
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					var str = ret.resp_result
+					if(str.includes('@')) {
+					  const parts = str.split('@');
+					  this.hform.HBarCode = parts[0]
+					  this.hform.HProcNo = parts[1]
+					  this.getHBarCodeData(parts[0],1)
+					  // this.getHProcNoData(parts[0],parts[1])
+					}else{
+						this.hform.HBarCode = ret.resp_result
+						this.getHBarCodeData(ret.resp_result)
+					}
+				})
 				// const str = "GXLX250603001-01@10";
-				uni.scanCode({
-				    onlyFromCamera: true,
-					// autoZoom:false,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						var str = res.result
-						if(str.includes('@')) {
-						  const parts = str.split('@');
-						  this.hform.HBarCode = parts[0]
-						  this.hform.HProcNo = parts[1]
-						  this.getHBarCodeData(parts[0])
-						  // this.getHProcNoData(parts[0],parts[1])
-						}else{
-							this.hform.HBarCode = res.result
-							this.getHBarCodeData(res.result)
-						}
-				    }
-				});
+				// uni.scanCode({
+				//     onlyFromCamera: true,
+				// 	// autoZoom:false,
+				//     success: (res) => {
+				//         console.log('鏉$爜鍐呭锛�' + res.result);
+				// 		var str = res.result
+				// 		if(str.includes('@')) {
+				// 		  const parts = str.split('@');
+				// 		  this.hform.HBarCode = parts[0]
+				// 		  this.hform.HProcNo = parts[1]
+				// 		  this.getHBarCodeData(parts[0],1)
+				// 		  // this.getHProcNoData(parts[0],parts[1])
+				// 		}else{
+				// 			this.hform.HBarCode = res.result
+				// 			this.getHBarCodeData(res.result)
+				// 		}
+				//     }
+				// });
 			},
 			toInCode(e){
 				var str = this.hform.HBarCode
@@ -590,7 +648,7 @@
 				  const parts = str.split('@');
 				  this.hform.HBarCode = parts[0]
 				  this.hform.HProcNo = parts[1]
-				  this.getHBarCodeData(parts[0])
+				  this.getHBarCodeData(parts[0],1)
 				  // this.getHProcNoData(parts[0],parts[1])
 				}else{
 					this.getHBarCodeData(this.hform.HBarCode)
@@ -598,14 +656,16 @@
 			},
 			//鎵祦姘村彿
 			toScanProcNo(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						this.hform.HProcNo = res.result
-						this.getHProcNoData(this.hform.HBarCode,res.result)
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					this.hform.HProcNo = ret.resp_result
+					this.getHProcNoData(this.hform.HBarCode,ret.resp_result)
+				})
 			},
 			//鏃ユ湡
 			HDateChange(e){
@@ -1054,7 +1114,7 @@
 						if(res.data.code == 1){
 							var data = res.data.data[0]
 							this.getHBarCodeData(data.HBarCode)
-							// this.getHProcNoData(data.HBarCode,data.HProcNo)
+							this.getHProcNoData(data.HBarCode,data.HProcNo)
 							
 							this.hform.HInterID= data.HInterID
 							this.hform.HBillNo= data.HBillNo
@@ -1117,7 +1177,7 @@
 					},
 				});
 			},
-			getHBarCodeData(HBarCode){
+			getHBarCodeData(HBarCode,e){
 				var barNo = HBarCode.substr(0, 2);
 				var barNo1 = HBarCode.substr(0, 4);
 				uni.request({
@@ -1155,7 +1215,9 @@
 							this.hform.HCenterID= data.HCenterID
 							this.hform.NoOutboundHqty= (data.娴佽浆鍗℃暟閲� - data.鍑虹珯鎶ュ簾鍏宠仈鏁伴噺 - data.鍑虹珯鍏宠仈鏁伴噺)
 							
-							this.getHProcNoData(this.hform.HBarCode,this.hform.HProcNo)
+							if(e){
+								this.getHProcNoData(this.hform.HBarCode,this.hform.HProcNo)
+							}
 						}else{
 							uni.showToast({
 								title:res.data.Message,
@@ -1312,7 +1374,12 @@
 									    }
 									});
 								}
-            				}
+            				}else{
+								uni.showToast({
+									title:res.data.Message,
+									icon:'none'
+								})
+							}
             			},
             			fail: (res) => {
             				console.log(res);
diff --git a/pages/guzhangdengji/form.vue b/pages/guzhangdengji/form.vue
index 5d20128..4dd4ac3 100644
--- a/pages/guzhangdengji/form.vue
+++ b/pages/guzhangdengji/form.vue
@@ -161,35 +161,37 @@
         methods: {
 			//鎵爜
 			toScanCode(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						uni.request({
-						    url: this.serverUrl + '/Gy_EquipFileMain/Gy_MouldFileBillBarCodeInfo', 
-							data: { HBarCode: res.result },
-						    success: (res) => {
-						        console.log(res.data);
-								if(res.data.count == 1){
-									var data = res.data.list[0][0]
-									this.hform.HEquipID = data.hmainid
-									this.hform.HEquipName = data.璁惧鍚嶇О
-								}
-								uni.showToast({
-									title:res.data.Message,
-									icon:'none'
-								})
-							},
-							fail: (res) => {
-								console.log(res);
-								uni.showToast({
-									title:'鎺ュ彛璇锋眰澶辫触',
-									icon:'none'
-								})
-							},
-						});
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					uni.request({
+					    url: this.serverUrl + '/Gy_EquipFileMain/Gy_MouldFileBillBarCodeInfo', 
+						data: { HBarCode: ret.resp_result },
+					    success: (res) => {
+					        console.log(res.data);
+							if(res.data.count == 1){
+								var data = res.data.list[0][0]
+								this.hform.HEquipID = data.hmainid
+								this.hform.HEquipName = data.璁惧鍚嶇О
+							}
+							uni.showToast({
+								title:res.data.Message,
+								icon:'none'
+							})
+						},
+						fail: (res) => {
+							console.log(res);
+							uni.showToast({
+								title:'鎺ュ彛璇锋眰澶辫触',
+								icon:'none'
+							})
+						},
+					});
+				})
 			},
 			// upCode(){
 			// 	uni.request({
diff --git a/pages/qitachuku/form.vue b/pages/qitachuku/form.vue
index 1e5a499..ceaac06 100644
--- a/pages/qitachuku/form.vue
+++ b/pages/qitachuku/form.vue
@@ -388,19 +388,21 @@
 		methods: {
 			//鎵爜
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						if (this.hform.HBarCode == '*') {
-							this.hform.HBarCode = this.hform.HBarCode + res.result
-						} else {
-							this.hform.HBarCode = res.result
-						}
-
-						this.getCode(this.hform.HBarCode)
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					if (this.hform.HBarCode == '*') {
+						this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					} else {
+						this.hform.HBarCode = ret.resp_result
 					}
-				});
+					
+					this.getCode(this.hform.HBarCode)
+				})
 			},
 			//閫夋嫨浠撳簱
 			HWHNameChange(e) {
diff --git a/pages/qitachuku_v2/form.vue b/pages/qitachuku_v2/form.vue
index 3ad1fd3..71a76f5 100644
--- a/pages/qitachuku_v2/form.vue
+++ b/pages/qitachuku_v2/form.vue
@@ -434,19 +434,21 @@
 			},
 			//鎵爜
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						if (this.hform.HBarCode == '*') {
-							this.hform.HBarCode = this.hform.HBarCode + res.result
-						} else {
-							this.hform.HBarCode = res.result
-						}
-
-						this.getCode(this.hform.HBarCode)
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					if (this.hform.HBarCode == '*') {
+						this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					} else {
+						this.hform.HBarCode = ret.resp_result
 					}
-				});
+					
+					this.getCode(this.hform.HBarCode)
+				})
 			},
 			showBillList() {
 				this.$refs.billList.showPopup()
diff --git a/pages/qitachukujiaoyan/detail.vue b/pages/qitachukujiaoyan/detail.vue
index 94779b5..f64e2c3 100644
--- a/pages/qitachukujiaoyan/detail.vue
+++ b/pages/qitachukujiaoyan/detail.vue
@@ -251,36 +251,40 @@
 		methods: {
 			//鎵爜
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						// if(this.hform.HBarCode == '*'){
-						// 	this.hform.HBarCode = this.hform.HBarCode + res.result
-						// }else{
-						// 	this.hform.HBarCode = res.result
-						// }
-						this.hform.HBarCode = res.result
-						// this.GetMeesageByBillNo(this.hform.HBarCode)
-						this.getCode(this.hform.HBarCode)
-					}
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					// if(this.hform.HBarCode == '*'){
+					// 	this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					// }else{
+					// 	this.hform.HBarCode = ret.resp_result
+					// }
+					this.hform.HBarCode = ret.resp_result
+					// this.GetMeesageByBillNo(this.hform.HBarCode)
+					this.getCode(this.hform.HBarCode)
+				})
 			},
 			toScanBillCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						// if(this.hform.HBarCode == '*'){
-						// 	this.hform.HBarCode = this.hform.HBarCode + res.result
-						// }else{
-						// 	this.hform.HBarCode = res.result
-						// }
-
-						this.hform.HBillNo = res.result
-						this.GetMeesageByBillNo(this.hform.HBillNo)
-					}
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					// if(this.hform.HBarCode == '*'){
+					// 	this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					// }else{
+					// 	this.hform.HBarCode = ret.resp_result
+					// }
+					
+					this.hform.HBillNo = ret.resp_result
+					this.GetMeesageByBillNo(this.hform.HBillNo)
+				})
 			},
 			//鎵弿鍗曟嵁鍙锋潯鐮�
 			GetMeesageByBillNo(e) {
diff --git a/pages/qitaruku/form.vue b/pages/qitaruku/form.vue
index 39599d3..3afa7fa 100644
--- a/pages/qitaruku/form.vue
+++ b/pages/qitaruku/form.vue
@@ -359,19 +359,21 @@
 		methods: {
 			//鎵爜
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						if (this.hform.HBarCode == '*') {
-							this.hform.HBarCode = this.hform.HBarCode + res.result
-						} else {
-							this.hform.HBarCode = res.result
-						}
-
-						this.getCode(this.hform.HBarCode)
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					if (this.hform.HBarCode == '*') {
+						this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					} else {
+						this.hform.HBarCode = ret.resp_result
 					}
-				});
+					
+					this.getCode(this.hform.HBarCode)
+				})
 			},
 			//鎵叾浠�(浠撳簱锛屼粨浣�)
 			// toScanData(e){
diff --git a/pages/qitaruku_v2/form.vue b/pages/qitaruku_v2/form.vue
index 287e558..c49b025 100644
--- a/pages/qitaruku_v2/form.vue
+++ b/pages/qitaruku_v2/form.vue
@@ -457,19 +457,21 @@
 			},
 			//鎵爜
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						if (this.hform.HBarCode == '*') {
-							this.hform.HBarCode = this.hform.HBarCode + res.result
-						} else {
-							this.hform.HBarCode = res.result
-						}
-
-						this.getCode(this.hform.HBarCode)
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					if (this.hform.HBarCode == '*') {
+						this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					} else {
+						this.hform.HBarCode = ret.resp_result
 					}
-				});
+					
+					this.getCode(this.hform.HBarCode)
+				})
 			},
 			showBillList() {
 				this.$refs.billList.showPopup()
diff --git a/pages/qitarukujiaoyan/form.vue b/pages/qitarukujiaoyan/form.vue
index 817a621..5640703 100644
--- a/pages/qitarukujiaoyan/form.vue
+++ b/pages/qitarukujiaoyan/form.vue
@@ -253,36 +253,40 @@
 		methods: {
 			//鎵爜
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						// if(this.hform.HBarCode == '*'){
-						// 	this.hform.HBarCode = this.hform.HBarCode + res.result
-						// }else{
-						// 	this.hform.HBarCode = res.result
-						// }
-						this.hform.HBarCode = res.result
-						// this.GetMeesageByBillNo(this.hform.HBarCode)
-						this.getCode(this.hform.HBarCode)
-					}
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					// if(this.hform.HBarCode == '*'){
+					// 	this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					// }else{
+					// 	this.hform.HBarCode = ret.resp_result
+					// }
+					this.hform.HBarCode = ret.resp_result
+					// this.GetMeesageByBillNo(this.hform.HBarCode)
+					this.getCode(this.hform.HBarCode)
+				})
 			},
 			toScanBillCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						// if(this.hform.HBarCode == '*'){
-						// 	this.hform.HBarCode = this.hform.HBarCode + res.result
-						// }else{
-						// 	this.hform.HBarCode = res.result
-						// }
-
-						this.hform.HBillNo = res.result
-						this.GetMeesageByBillNo(this.hform.HBillNo)
-					}
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					// if(this.hform.HBarCode == '*'){
+					// 	this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					// }else{
+					// 	this.hform.HBarCode = ret.resp_result
+					// }
+					
+					this.hform.HBillNo = ret.resp_result
+					this.GetMeesageByBillNo(this.hform.HBillNo)
+				})
 			},
 			//鎵弿鍗曟嵁鍙锋潯鐮�
 			GetMeesageByBillNo(e) {
diff --git a/pages/shebeiweixiu/form.vue b/pages/shebeiweixiu/form.vue
index 52125ee..d412ac5 100644
--- a/pages/shebeiweixiu/form.vue
+++ b/pages/shebeiweixiu/form.vue
@@ -219,35 +219,37 @@
         methods: {
 			//鎵爜
 			toScanCode(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						uni.request({
-						    url: this.serverUrl + '/Gy_EquipFileMain/Gy_MouldFileBillBarCodeInfo', 
-							data: { HBarCode: res.result },
-						    success: (res) => {
-						        console.log(res.data);
-								if(res.data.count == 1){
-									var data = res.data.list[0][0]
-									this.hform.HEquipID = data.hmainid
-									this.hform.HEquipName = data.璁惧鍚嶇О
-								}
-								uni.showToast({
-									title:res.data.Message,
-									icon:'none'
-								})
-							},
-							fail: (res) => {
-								console.log(res);
-								uni.showToast({
-									title:'鎺ュ彛璇锋眰澶辫触',
-									icon:'none'
-								})
-							},
-						});
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					uni.request({
+					    url: this.serverUrl + '/Gy_EquipFileMain/Gy_MouldFileBillBarCodeInfo', 
+						data: { HBarCode: ret.resp_result },
+					    success: (res) => {
+					        console.log(res.data);
+							if(res.data.count == 1){
+								var data = res.data.list[0][0]
+								this.hform.HEquipID = data.hmainid
+								this.hform.HEquipName = data.璁惧鍚嶇О
+							}
+							uni.showToast({
+								title:res.data.Message,
+								icon:'none'
+							})
+						},
+						fail: (res) => {
+							console.log(res);
+							uni.showToast({
+								title:'鎺ュ彛璇锋眰澶辫触',
+								icon:'none'
+							})
+						},
+					});
+				})
 			},
 			//缁翠慨寮�濮嬮�夋嫨
 			HBeginDateChange(e){
diff --git a/pages/shengchanbuliao/form.vue b/pages/shengchanbuliao/form.vue
index 8ecaf10..6f66281 100644
--- a/pages/shengchanbuliao/form.vue
+++ b/pages/shengchanbuliao/form.vue
@@ -406,19 +406,21 @@
 			},
 			//鎵爜
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						if (this.hform.HBarCode == '*') {
-							this.hform.HBarCode = this.hform.HBarCode + res.result
-						} else {
-							this.hform.HBarCode = res.result
-						}
-
-						this.getCode(this.hform.HBarCode)
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					if (this.hform.HBarCode == '*') {
+						this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					} else {
+						this.hform.HBarCode = ret.resp_result
 					}
-				});
+					
+					this.getCode(this.hform.HBarCode)
+				})
 			},
 			showBillList() {
 				this.$refs.billList.showPopup()
diff --git a/pages/shengchanbuliaojiaoyan/form.vue b/pages/shengchanbuliaojiaoyan/form.vue
index 6d25538..d3deb1b 100644
--- a/pages/shengchanbuliaojiaoyan/form.vue
+++ b/pages/shengchanbuliaojiaoyan/form.vue
@@ -266,35 +266,39 @@
 		methods: {
 			//鏉$爜鍙锋壂鐮�
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						// if(this.hform.HBarCode == '*'){
-						// 	this.hform.HBarCode = this.hform.HBarCode + res.result
-						// }else{
-						// 	this.hform.HBarCode = res.result
-						// }
-						this.hform.HBarCode = res.result
-						this.getCode(this.hform.HBarCode)
-					}
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					// if(this.hform.HBarCode == '*'){
+					// 	this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					// }else{
+					// 	this.hform.HBarCode = ret.resp_result
+					// }
+					this.hform.HBarCode = ret.resp_result
+					this.getCode(this.hform.HBarCode)
+				})
 			},
 			//鎵弿鍗曟嵁鍙锋潯鐮�
 			toScanBillCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						// if(this.hform.HBarCode == '*'){
-						// 	this.hform.HBarCode = this.hform.HBarCode + res.result
-						// }else{
-						// 	this.hform.HBarCode = res.result
-						// }
-						this.hform.HBillNo = res.result
-						this.GetMeesageByBillNo(this.hform.HBillNo)
-					}
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					// if(this.hform.HBarCode == '*'){
+					// 	this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					// }else{
+					// 	this.hform.HBarCode = ret.resp_result
+					// }
+					this.hform.HBillNo = ret.resp_result
+					this.GetMeesageByBillNo(this.hform.HBillNo)
+				})
 			},
 			//鎵弿鍗曟嵁鍙锋潯鐮�
 			GetMeesageByBillNo(e) {
diff --git a/pages/shengchandiaobo/form.vue b/pages/shengchandiaobo/form.vue
index 4507665..eae6c2d 100644
--- a/pages/shengchandiaobo/form.vue
+++ b/pages/shengchandiaobo/form.vue
@@ -250,14 +250,16 @@
 			},
 			//鎵爜
 			toScanCode(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						this.hform.HBillNo = res.result
-						this.GetMeesageByBillNo(this.hform.HBillNo)
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					this.hform.HBillNo = ret.resp_result
+					this.GetMeesageByBillNo(this.hform.HBillNo)
+				})
 			},
 			//鎵弿鍗曟嵁鍙锋潯鐮�
 			GetMeesageByBillNo(e){
diff --git a/pages/shengchanlingliao/form.vue b/pages/shengchanlingliao/form.vue
index de87e43..a1a5499 100644
--- a/pages/shengchanlingliao/form.vue
+++ b/pages/shengchanlingliao/form.vue
@@ -236,19 +236,21 @@
 			},
 			//鎵爜
 			toScanCode(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						// if(this.hform.HBarCode == '*'){
-						// 	this.hform.HBarCode = this.hform.HBarCode + res.result
-						// }else{
-						// 	this.hform.HBarCode = res.result
-						// }
-						this.hform.HBillNo = res.result
-						this.GetMeesageByBillNo(res.result)
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					// if(this.hform.HBarCode == '*'){
+					// 	this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					// }else{
+					// 	this.hform.HBarCode = ret.resp_result
+					// }
+					this.hform.HBillNo = ret.resp_result
+					this.GetMeesageByBillNo(ret.resp_result)
+				})
 			},
 			//鎵弿鍗曟嵁鍙锋潯鐮�
 			GetMeesageByBillNo(e){
diff --git a/pages/shengchanlingliaoshengdan/form.vue b/pages/shengchanlingliaoshengdan/form.vue
index 3b9af30..d8b67c6 100644
--- a/pages/shengchanlingliaoshengdan/form.vue
+++ b/pages/shengchanlingliaoshengdan/form.vue
@@ -409,19 +409,21 @@
 			},
 			//鎵爜
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						if (this.hform.HBarCode == '*') {
-							this.hform.HBarCode = this.hform.HBarCode + res.result
-						} else {
-							this.hform.HBarCode = res.result
-						}
-
-						this.getCode(this.hform.HBarCode)
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					if (this.hform.HBarCode == '*') {
+						this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					} else {
+						this.hform.HBarCode = ret.resp_result
 					}
-				});
+					
+					this.getCode(this.hform.HBarCode)
+				})
 			},
 			showBillList() {
 				this.$refs.billList.showPopup()
diff --git a/pages/shengchanruku/form.vue b/pages/shengchanruku/form.vue
index 03d0fc7..91fee13 100644
--- a/pages/shengchanruku/form.vue
+++ b/pages/shengchanruku/form.vue
@@ -221,14 +221,16 @@
 			},
 			//鎵爜
 			toScanCode(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						this.hform.HBillNo = res.result
-						this.GetMeesageByBillNo(this.hform.HBillNo)
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					this.hform.HBillNo = ret.resp_result
+					this.GetMeesageByBillNo(this.hform.HBillNo)
+				})
 			},
 			//鎵弿鍗曟嵁鍙锋潯鐮�
 			GetMeesageByBillNo(e){
diff --git a/pages/shengchanrukushengdan/form.vue b/pages/shengchanrukushengdan/form.vue
index c5dcbd6..0c0f2e0 100644
--- a/pages/shengchanrukushengdan/form.vue
+++ b/pages/shengchanrukushengdan/form.vue
@@ -407,19 +407,21 @@
 			},
 			//鎵爜
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						if (this.hform.HBarCode == '*') {
-							this.hform.HBarCode = this.hform.HBarCode + res.result
-						} else {
-							this.hform.HBarCode = res.result
-						}
-
-						this.getCode(this.hform.HBarCode)
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					if (this.hform.HBarCode == '*') {
+						this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					} else {
+						this.hform.HBarCode = ret.resp_result
 					}
-				});
+					
+					this.getCode(this.hform.HBarCode)
+				})
 			},
 			showBillList() {
 				this.$refs.billList.showPopup()
diff --git a/pages/shouliaotongzhi/table.vue b/pages/shouliaotongzhi/table.vue
index c0992dc..38942ef 100644
--- a/pages/shouliaotongzhi/table.vue
+++ b/pages/shouliaotongzhi/table.vue
@@ -83,15 +83,16 @@
 			},
 			//鎵爜
 			toScanCode(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						this.HBarCode = res.result
-						
-						this.getCode(this.HBarCode)
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					this.HBarCode = ret.resp_result
+					this.getCode(this.HBarCode)
+				})
 			},
 			//鎵潯鐮佸鐞�
 			getCode(HBarCode){
diff --git a/pages/tiaomadaying/tiaomadaying.vue b/pages/tiaomadaying/tiaomadaying.vue
index 5692644..6724a66 100644
--- a/pages/tiaomadaying/tiaomadaying.vue
+++ b/pages/tiaomadaying/tiaomadaying.vue
@@ -363,49 +363,52 @@
 				}
 			},
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						if (CommonUtils.isEmpty(res.result) === false) {
-							console.log('鏉$爜鍐呭锛�' + res.result);
-							this.lailiaoInfo.barCodeNo = res.result;
-							if (res.result.includes("@") === false) {
-								return uni.showToast({
-									icon: 'none',
-									title: '鏉$爜鏍煎紡閿欒锛岃閲嶆柊鎵弿...'
-								})
-							}
-							let barCodeInfo = res.result.split("@")
-							let [PurchaseBillNo, Row] = barCodeInfo
-							this.lailiaoInfo.HBillNo = PurchaseBillNo,
-								this.lailiaoInfo.HBillLineNo = Row
-							console.log({
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					if (CommonUtils.isEmpty(ret.resp_result) === false) {
+						console.log('鏉$爜鍐呭锛�' + ret.resp_result);
+						this.lailiaoInfo.barCodeNo = ret.resp_result;
+						if (ret.resp_result.includes("@") === false) {
+							return uni.showToast({
+								icon: 'none',
+								title: '鏉$爜鏍煎紡閿欒锛岃閲嶆柊鎵弿...'
+							})
+						}
+						let barCodeInfo = ret.resp_result.split("@")
+						let [PurchaseBillNo, Row] = barCodeInfo
+						this.lailiaoInfo.HBillNo = PurchaseBillNo,
+							this.lailiaoInfo.HBillLineNo = Row
+						console.log({
+							sWhere: ` and 鍗曟嵁鍙� = '${PurchaseBillNo}'`,
+							user: this.userInfo.Czymc,
+						})
+						CommonUtils.doRequest(
+							"/Cg_POOrderBill/list", {
 								sWhere: ` and 鍗曟嵁鍙� = '${PurchaseBillNo}'`,
 								user: this.userInfo.Czymc,
-							})
-							CommonUtils.doRequest(
-								"/Cg_POOrderBill/list", {
-									sWhere: ` and 鍗曟嵁鍙� = '${PurchaseBillNo}'`,
-									user: this.userInfo.Czymc,
-								},
-								(res) => {
-									console.log('閲囪喘璁㈠崟: ', res)
-									let {
-										data,
-										count
-									} = res.data
-									if (count > 0) {
-										this.setLailiaoInfo(data, Row)
-									}
-								},
-								(error) => {
-
+							},
+							(res) => {
+								console.log('閲囪喘璁㈠崟: ', res)
+								let {
+									data,
+									count
+								} = res.data
+								if (count > 0) {
+									this.setLailiaoInfo(data, Row)
 								}
-							)
-
-						}
+							},
+							(error) => {
+					
+							}
+						)
+					
 					}
-				});
+				})
 			},
 			GenereateBarCode() {
 				let sMain = []
diff --git a/pages/weiwaibuliaojiaoyan/form.vue b/pages/weiwaibuliaojiaoyan/form.vue
index 0e31ece..9859f10 100644
--- a/pages/weiwaibuliaojiaoyan/form.vue
+++ b/pages/weiwaibuliaojiaoyan/form.vue
@@ -247,36 +247,40 @@
 		methods: {
 			//鎵爜
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						// if(this.hform.HBarCode == '*'){
-						// 	this.hform.HBarCode = this.hform.HBarCode + res.result
-						// }else{
-						// 	this.hform.HBarCode = res.result
-						// }
-						this.hform.HBarCode = res.result
-						// this.GetMeesageByBillNo(this.hform.HBarCode)
-						this.getCode(this.hform.HBarCode)
-					}
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					// if(this.hform.HBarCode == '*'){
+					// 	this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					// }else{
+					// 	this.hform.HBarCode = ret.resp_result
+					// }
+					this.hform.HBarCode = ret.resp_result
+					// this.GetMeesageByBillNo(this.hform.HBarCode)
+					this.getCode(this.hform.HBarCode)
+				})
 			},
 			toScanBillCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						// if(this.hform.HBarCode == '*'){
-						// 	this.hform.HBarCode = this.hform.HBarCode + res.result
-						// }else{
-						// 	this.hform.HBarCode = res.result
-						// }
-						
-						this.hform.HBillNo = res.result
-						this.GetMeesageByBillNo(this.hform.HBillNo)
-					}
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					// if(this.hform.HBarCode == '*'){
+					// 	this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					// }else{
+					// 	this.hform.HBarCode = ret.resp_result
+					// }
+					
+					this.hform.HBillNo = ret.resp_result
+					this.GetMeesageByBillNo(this.hform.HBillNo)
+				})
 			},
 			//鎵弿鍗曟嵁鍙锋潯鐮�
 			GetMeesageByBillNo(e) {
diff --git a/pages/weiwaigxIn/form.vue b/pages/weiwaigxIn/form.vue
index 79d87d0..f3ea476 100644
--- a/pages/weiwaigxIn/form.vue
+++ b/pages/weiwaigxIn/form.vue
@@ -398,40 +398,81 @@
 			this.getHProcList()
 			this.getHSupList()
 			this.getHEmpList()
+			
+			this.getDefValByUser()
 		},
         methods: {
+			//閫氳繃鐧诲綍鐢ㄦ埛鑾峰彇榛樿鍊�
+			getDefValByUser(){
+				uni.request({
+				    url: this.serverUrl + '/Cj_StationInBill/GetDefValByUser', 
+					type: "GET",
+					async: false,
+					data: { "Czybm": this.userInfo.Czybm, "Czymc":  this.userInfo.Czymc },
+				    success: (res) => {
+						console.log(res.data)
+						if(res.data.count == 1){
+							var data = res.data.data[0]
+							this.hform.HGroupID = data.HGroupID
+							this.hform.HGroupName = data.鐢熶骇鐝粍鍚嶇О
+							this.hform.HEmpID = data.HEmpID
+							this.hform.HEmpName = data.鎿嶄綔鍛樺悕绉�
+							this.hform.HEmpNumber = data.鎿嶄綔鍛樹唬鐮�
+							this.hform.HSourceID = data.HSourceID
+							this.hform.HSourceName = data.鐢熶骇璧勬簮鍚嶇О
+							this.hform.HCenterID = data.HWorkCenterID
+							this.hform.HCenterName = data.宸ヤ綔涓績鍚嶇О
+							this.hform.HEmpName_second = data.鎿嶄綔鍛樺悕绉�
+						}else{
+							uni.showToast({
+								title:'鑾峰彇鐢熶骇鐝粍淇℃伅澶辫触',
+								icon:'none'
+							})
+						}
+					},
+					fail: (res) => {
+						console.log(res);
+						uni.showToast({
+							title:'鑾峰彇鐢熶骇鐝粍淇℃伅澶辫触',
+							icon:'none'
+						})
+					},
+				});
+			},
 			//鎵爜
 			toScanCode(){
-				// this.hform.HBarCode = 'OP000021_01'
-				// this.getHBarCodeData('OP000021_01')
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						var str = res.result
-						if(str.includes('@')) {
-						  const parts = str.split('@');
-						  this.hform.HBarCode = parts[0]
-						  this.hform.HProcNo = parts[1]
-						  this.getHBarCodeData(parts[0])
-						  // this.getHProcNoData(parts[0],parts[1])
-						}else{
-							this.hform.HBarCode = res.result
-							this.getHBarCodeData(res.result)
-						}
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					var str = ret.resp_result
+					if(str.includes('@')) {
+					  const parts = str.split('@');
+					  this.hform.HBarCode = parts[0]
+					  this.hform.HProcNo = parts[1]
+					  this.getHBarCodeData(parts[0],1)
+					  // this.getHProcNoData(parts[0],parts[1])
+					}else{
+						this.hform.HBarCode = ret.resp_result
+						this.getHBarCodeData(ret.resp_result)
+					}
+				})
 			},
 			//鎵祦姘村彿
 			toScanProcNo(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						this.hform.HProcNo = res.result
-						this.getHProcNoData(this.hform.HBarCode,res.result)
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					this.hform.HProcNo = ret.resp_result
+					this.getHProcNoData(this.hform.HBarCode,ret.resp_result)
+				})
 			},
 			//鏃ユ湡
 			HDateChange(e){
@@ -632,7 +673,7 @@
 						if(res.data.code == 1){
 							var data = res.data.data[0]
 							this.getHBarCodeData(data.HBarCode)
-							// this.getHProcNoData(data.HBarCode,data.HProcNo)
+							this.getHProcNoData(data.HBarCode,data.HProcNo)
 							
 							this.hform.HInterID= data.HInterID
 							this.hform.HBillNo= data.HBillNo
@@ -694,7 +735,7 @@
 					},
 				});
 			},
-			getHBarCodeData(HBarCode){
+			getHBarCodeData(HBarCode,e){
 				uni.request({
 				    url: this.serverUrl + '/Cj_StationEntrustInBill/txtHBarCode_KeyDown', 
 					data: {HBarCode: HBarCode},
@@ -729,6 +770,10 @@
                             this.hform.HDept= this.userInfo.HDept
                             this.hform.HProcExchHinteID= data.hmainid
                             this.hform.HPRDOrg= data.缁勭粐
+							
+							if(e){
+								this.getHProcNoData(this.hform.HBarCode,this.hform.HProcNo)
+							}
 						}else{
 							uni.showToast({
 								title:res.data.Message,
@@ -875,7 +920,12 @@
 									    }
 									});
 								}
-            				}
+            				}else{
+								uni.showToast({
+									title:res.data.Message,
+									icon:'none'
+								})
+							}
             			},
             			fail: (res) => {
             				console.log(res);
diff --git a/pages/weiwaigxOut/form.vue b/pages/weiwaigxOut/form.vue
index 96a808d..d507b24 100644
--- a/pages/weiwaigxOut/form.vue
+++ b/pages/weiwaigxOut/form.vue
@@ -359,10 +359,10 @@
 					HBillNo:'',
 					HBarCode:'',
 					HQty:'',
-					HPieceQty:'',
-					HWasterQty:'',
+					HPieceQty:0,
+					HWasterQty:0,
 					HEmpName:'',
-					HEmpID:'',
+					HEmpID:0,
 					HInnerBillNo:'',
 					HWWWorkOrderBillNo:'',
 					HRemark:'',
@@ -372,7 +372,7 @@
 					HProcExchBillNo:'',
 					HMaterNumber:'',
 					HMaterName:'',
-					HMaterID:'',
+					HMaterID:0,
 					HMaterModel:'',
 					HSupName:'',
 					HSupID:'',
@@ -447,31 +447,81 @@
 			this.getHProcList()
 			this.getHSupList()
 			this.getHEmpList()
+			
+			this.getDefValByUser()
 		},
         methods: {
+			//閫氳繃鐧诲綍鐢ㄦ埛鑾峰彇榛樿鍊�
+			getDefValByUser(){
+				uni.request({
+				    url: this.serverUrl + '/Cj_StationInBill/GetDefValByUser', 
+					type: "GET",
+					async: false,
+					data: { "Czybm": this.userInfo.Czybm, "Czymc":  this.userInfo.Czymc },
+				    success: (res) => {
+						console.log(res.data)
+						if(res.data.count == 1){
+							var data = res.data.data[0]
+							this.hform.HGroupID = data.HGroupID
+							this.hform.HGroupName = data.鐢熶骇鐝粍鍚嶇О
+							this.hform.HEmpID = data.HEmpID
+							this.hform.HEmpName = data.鎿嶄綔鍛樺悕绉�
+							this.hform.HEmpNumber = data.鎿嶄綔鍛樹唬鐮�
+							this.hform.HSourceID = data.HSourceID
+							this.hform.HSourceName = data.鐢熶骇璧勬簮鍚嶇О
+							this.hform.HCenterID = data.HWorkCenterID
+							this.hform.HCenterName = data.宸ヤ綔涓績鍚嶇О
+							this.hform.HEmpName_second = data.鎿嶄綔鍛樺悕绉�
+						}else{
+							uni.showToast({
+								title:'鑾峰彇鐢熶骇鐝粍淇℃伅澶辫触',
+								icon:'none'
+							})
+						}
+					},
+					fail: (res) => {
+						console.log(res);
+						uni.showToast({
+							title:'鑾峰彇鐢熶骇鐝粍淇℃伅澶辫触',
+							icon:'none'
+						})
+					},
+				});
+			},
 			//鎵爜
 			toScanCode(){
-				this.hform.HBarCode = 'OP000021_01'
-				this.getHBarCodeData('OP000021_01')
-				// uni.scanCode({
-				//     onlyFromCamera: true,
-				//     success: (res) => {
-				//         console.log('鏉$爜鍐呭锛�' + res.result);
-				// 		this.hform.HBarCode = res.result
-				// 		this.getHBarCodeData(res.result)
-				//     }
-				// });
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					var str = ret.resp_result
+					if(str.includes('@')) {
+					  const parts = str.split('@');
+					  this.hform.HBarCode = parts[0]
+					  this.hform.HProcNo = parts[1]
+					  this.getHBarCodeData(parts[0],1)
+					  // this.getHProcNoData(parts[0],parts[1])
+					}else{
+						this.hform.HBarCode = ret.resp_result
+						this.getHBarCodeData(ret.resp_result)
+					}
+				})
 			},
 			//鎵祦姘村彿
 			toScanProcNo(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						this.hform.HProcNo = res.result
-						this.getHProcNoData(this.hform.HBarCode,res.result)
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+						this.hform.HProcNo = ret.resp_result
+						this.getHProcNoData(this.hform.HBarCode,ret.resp_result)
+				})
 			},
 			//鏃ユ湡
 			HDateChange(e){
@@ -771,7 +821,7 @@
 					},
 				});
 			},
-			getHBarCodeData(HBarCode){
+			getHBarCodeData(HBarCode,e){
 				uni.request({
 				    url: this.serverUrl + '/Cj_StationEntrustInBill/txtHBarCode_KeyDown', 
 					data: {HBarCode: HBarCode},
@@ -807,6 +857,9 @@
                             this.hform.HProcExchHinteID= data.hmainid
                             this.hform.HPRDOrg= data.缁勭粐
 							
+							if(e){
+								this.getHProcNoData(this.hform.HBarCode,this.hform.HProcNo)
+							}
 						}else{
 							uni.showToast({
 								title:res.data.Message,
@@ -947,7 +1000,12 @@
 									    }
 									});
 								}
-            				}
+            				}else{
+								uni.showToast({
+									title:res.data.Message,
+									icon:'none'
+								})
+							}
             			},
             			fail: (res) => {
             				console.log(res);
diff --git a/pages/weiwailingliao/form.vue b/pages/weiwailingliao/form.vue
index 4e3c0ba..c21e55b 100644
--- a/pages/weiwailingliao/form.vue
+++ b/pages/weiwailingliao/form.vue
@@ -406,19 +406,21 @@
 			},
 			//鎵爜
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						if (this.hform.HBarCode == '*') {
-							this.hform.HBarCode = this.hform.HBarCode + res.result
-						} else {
-							this.hform.HBarCode = res.result
-						}
-
-						this.getCode(this.hform.HBarCode)
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					if (this.hform.HBarCode == '*') {
+						this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					} else {
+						this.hform.HBarCode = ret.resp_result
 					}
-				});
+					
+					this.getCode(this.hform.HBarCode)
+				})
 			},
 			showBillList() {
 				this.$refs.billList.showPopup()
diff --git a/pages/weiwailingliaojiaoyan/form.vue b/pages/weiwailingliaojiaoyan/form.vue
index a38f3ed..662f174 100644
--- a/pages/weiwailingliaojiaoyan/form.vue
+++ b/pages/weiwailingliaojiaoyan/form.vue
@@ -254,36 +254,40 @@
 		methods: {
 			//鎵爜
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						// if(this.hform.HBarCode == '*'){
-						// 	this.hform.HBarCode = this.hform.HBarCode + res.result
-						// }else{
-						// 	this.hform.HBarCode = res.result
-						// }
-						this.hform.HBarCode = res.result
-						// this.GetMeesageByBillNo(this.hform.HBarCode)
-						this.getCode(this.hform.HBarCode)
-					}
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					// if(this.hform.HBarCode == '*'){
+					// 	this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					// }else{
+					// 	this.hform.HBarCode = ret.resp_result
+					// }
+					this.hform.HBarCode = ret.resp_result
+					// this.GetMeesageByBillNo(this.hform.HBarCode)
+					this.getCode(this.hform.HBarCode)
+				})
 			},
 			toScanBillCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						// if(this.hform.HBarCode == '*'){
-						// 	this.hform.HBarCode = this.hform.HBarCode + res.result
-						// }else{
-						// 	this.hform.HBarCode = res.result
-						// }
-
-						this.hform.HBillNo = res.result
-						this.GetMeesageByBillNo(this.hform.HBillNo)
-					}
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					// if(this.hform.HBarCode == '*'){
+					// 	this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					// }else{
+					// 	this.hform.HBarCode = ret.resp_result
+					// }
+					
+					this.hform.HBillNo = ret.resp_result
+					this.GetMeesageByBillNo(this.hform.HBillNo)
+				})
 			},
 			//鎵弿鍗曟嵁鍙锋潯鐮�
 			GetMeesageByBillNo(e) {
diff --git a/pages/wuliaosaoma/wuliaosaoma.vue b/pages/wuliaosaoma/wuliaosaoma.vue
index 60c6b6f..3cb1e8f 100644
--- a/pages/wuliaosaoma/wuliaosaoma.vue
+++ b/pages/wuliaosaoma/wuliaosaoma.vue
@@ -54,50 +54,53 @@
 		},
 		methods: {
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						if (this.CommonUtils.isEmpty(res.result) === false) {
-							console.log('鏉$爜鍐呭锛�' + res.result);
-							this.HBillNo = res.result
-							CommonUtils.doRequest(
-								"/Cg_POInStockBill/page", {
-									sWhere: ` and 鍗曟嵁鍙�='${res.result}'`,
-									user: this.userInfo.HEmpName,
-									page: this.pageInfo.page,
-									size: this.pageInfo.size
-								},
-								function(res) {
-									console.log(res)
-									let res1 = res.data
-
-									let {
-										count,
-										data
-									} = res1;
-									if (count > 0) {
-										console.log(data)
-										// this.HMaterList = data.reduce((acc, obj) => {
-										// 	acc.push({
-										// 		"HMaterID": obj['HMaterID'],
-										// 		"HMaterNo": obj['鐗╂枡浠g爜'],
-										// 		"HMaterName": obj['鐗╂枡鍚嶇О'],
-										// 		"HMaterType": obj['瑙勬牸鍨嬪彿'],
-										// 		"HQty": obj['鏁伴噺'],
-										// 		"HBarCode": "",
-										// 		"HBillNo": obj['鍗曟嵁鍙�']
-										// 	})
-										// }, [])
-
-									}
-								},
-								function(err) {
-									console.error(err)
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					if (this.CommonUtils.isEmpty(ret.resp_result) === false) {
+						console.log('鏉$爜鍐呭锛�' + ret.resp_result);
+						this.HBillNo = ret.resp_result
+						CommonUtils.doRequest(
+							"/Cg_POInStockBill/page", {
+								sWhere: ` and 鍗曟嵁鍙�='${ret.resp_result}'`,
+								user: this.userInfo.HEmpName,
+								page: this.pageInfo.page,
+								size: this.pageInfo.size
+							},
+							function(res) {
+								console.log(res)
+								let res1 = res.data
+					
+								let {
+									count,
+									data
+								} = res1;
+								if (count > 0) {
+									console.log(data)
+									// this.HMaterList = data.reduce((acc, obj) => {
+									// 	acc.push({
+									// 		"HMaterID": obj['HMaterID'],
+									// 		"HMaterNo": obj['鐗╂枡浠g爜'],
+									// 		"HMaterName": obj['鐗╂枡鍚嶇О'],
+									// 		"HMaterType": obj['瑙勬牸鍨嬪彿'],
+									// 		"HQty": obj['鏁伴噺'],
+									// 		"HBarCode": "",
+									// 		"HBillNo": obj['鍗曟嵁鍙�']
+									// 	})
+									// }, [])
+					
 								}
-							)
-						}
+							},
+							function(err) {
+								console.error(err)
+							}
+						)
 					}
-				});
+				})
 			},
 		},
 		onload() {
diff --git a/pages/xiaoshouchuku/form.vue b/pages/xiaoshouchuku/form.vue
index 287b974..25ed18d 100644
--- a/pages/xiaoshouchuku/form.vue
+++ b/pages/xiaoshouchuku/form.vue
@@ -365,19 +365,21 @@
 			},
 			//鎵爜
 			toScanCode(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						if(this.hform.HBarCode == '*'){
-							this.hform.HBarCode = this.hform.HBarCode + res.result
-						}else{
-							this.hform.HBarCode = res.result
-						}
-						
-						this.getCode(this.hform.HBarCode)
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					if(this.hform.HBarCode == '*'){
+						this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					}else{
+						this.hform.HBarCode = ret.resp_result
+					}
+					
+					this.getCode(this.hform.HBarCode)
+				})
 			},
 			//鎵叾浠�(浠撳簱锛屼粨浣�)
 			// toScanData(e){
diff --git a/pages/xiaoshouchukujiaoyan/form.vue b/pages/xiaoshouchukujiaoyan/form.vue
index 0faea5d..e51841a 100644
--- a/pages/xiaoshouchukujiaoyan/form.vue
+++ b/pages/xiaoshouchukujiaoyan/form.vue
@@ -255,36 +255,40 @@
 		methods: {
 			//鎵爜
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						// if(this.hform.HBarCode == '*'){
-						// 	this.hform.HBarCode = this.hform.HBarCode + res.result
-						// }else{
-						// 	this.hform.HBarCode = res.result
-						// }
-						this.hform.HBarCode = res.result
-						// this.GetMeesageByBillNo(this.hform.HBarCode)
-						this.getCode(this.hform.HBarCode)
-					}
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					// if(this.hform.HBarCode == '*'){
+					// 	this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					// }else{
+					// 	this.hform.HBarCode = ret.resp_result
+					// }
+					this.hform.HBarCode = ret.resp_result
+					// this.GetMeesageByBillNo(this.hform.HBarCode)
+					this.getCode(this.hform.HBarCode)
+				})
 			},
 			toScanBillCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						console.log('鏉$爜鍐呭锛�' + res.result);
-						// if(this.hform.HBarCode == '*'){
-						// 	this.hform.HBarCode = this.hform.HBarCode + res.result
-						// }else{
-						// 	this.hform.HBarCode = res.result
-						// }
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					// if(this.hform.HBarCode == '*'){
+					// 	this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					// }else{
+					// 	this.hform.HBarCode = ret.resp_result
+					// }
 
-						this.hform.HBillNo = res.result
-						this.GetMeesageByBillNo(this.hform.HBillNo)
-					}
-				});
+					this.hform.HBillNo = ret.resp_result
+					this.GetMeesageByBillNo(this.hform.HBillNo)
+				})
 			},
 			//鎵弿鍗曟嵁鍙锋潯鐮�
 			GetMeesageByBillNo(e) {
diff --git a/pages/xiaoshoutuihuo/form.vue b/pages/xiaoshoutuihuo/form.vue
index df9f2e5..9577f8e 100644
--- a/pages/xiaoshoutuihuo/form.vue
+++ b/pages/xiaoshoutuihuo/form.vue
@@ -325,29 +325,33 @@
 			},
 			//鎵爜
 			toScanCode(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						if(this.hform.HBarCode == '*'){
-							this.hform.HBarCode = this.hform.HBarCode + res.result
-						}else{
-							this.hform.HBarCode = res.result
-						}
-						
-						this.getCode(this.hform.HBarCode)
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					if(this.hform.HBarCode == '*'){
+						this.hform.HBarCode = this.hform.HBarCode + ret.resp_result
+					}else{
+						this.hform.HBarCode = ret.resp_result
+					}
+					
+					this.getCode(this.hform.HBarCode)
+				})
 			},
 			toScanCodeA(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						this.hform.HSourceBillNo = res.result
-						this.getHBarCodeData(res.result)
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					this.hform.HSourceBillNo = ret.resp_result
+					this.getHBarCodeData(ret.resp_result)
+				})
 			},
 			//鏃ユ湡
 			HDateChange(e){

diff --git a/pages/shebeidangan/form.vue b/pages/shebeidangan/form.vue
index 6c7c55b..ca12485 100644
--- a/pages/shebeidangan/form.vue
+++ b/pages/shebeidangan/form.vue
@@ -364,36 +364,38 @@
         methods: {
 			//鎵爜
 			toScanCode(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						this.hform.HBarCode = res.result
-						// uni.request({
-						//     url: this.serverUrl + '/Gy_EquipFileMain/Gy_MouldFileBillBarCodeInfo', 
-						// 	data: { HBarCode: res.result },
-						//     success: (res) => {
-						//         console.log(res.data);
-						// 		var data = res.data.list[0][0]
-						// 		if(res.data.count == 1){
-						// 			this.hform.HEquipID = data.hmainid
-						// 			this.hform.HEquipName = data.璁惧鍚嶇О
-						// 		}
-						// 		uni.showToast({
-						// 			title:res.data.Message,
-						// 			icon:'none'
-						// 		})
-						// 	},
-						// 	fail: (res) => {
-						// 		console.log(res);
-						// 		uni.showToast({
-						// 			title:'鎺ュ彛璇锋眰澶辫触',
-						// 			icon:'none'
-						// 		})
-						// 	},
-						// });
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					this.hform.HBarCode = ret.resp_result
+					// uni.request({
+					//     url: this.serverUrl + '/Gy_EquipFileMain/Gy_MouldFileBillBarCodeInfo', 
+					// 	data: { HBarCode: ret.resp_result },
+					//     success: (res) => {
+					//         console.log(res.data);
+					// 		var data = res.data.list[0][0]
+					// 		if(res.data.count == 1){
+					// 			this.hform.HEquipID = data.hmainid
+					// 			this.hform.HEquipName = data.璁惧鍚嶇О
+					// 		}
+					// 		uni.showToast({
+					// 			title:res.data.Message,
+					// 			icon:'none'
+					// 		})
+					// 	},
+					// 	fail: (res) => {
+					// 		console.log(res);
+					// 		uni.showToast({
+					// 			title:'鎺ュ彛璇锋眰澶辫触',
+					// 			icon:'none'
+					// 		})
+					// 	},
+					// });
+				})
 			},
 			// upCode(){
 			// 	uni.request({
diff --git a/pages/shebeiguanli/form.vue b/pages/shebeiguanli/form.vue
index aafd004..be263e9 100644
--- a/pages/shebeiguanli/form.vue
+++ b/pages/shebeiguanli/form.vue
@@ -367,36 +367,38 @@
         methods: {
 			//鎵爜
 			toScanCode(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						this.hform.HBarCode = res.result
-						// uni.request({
-						//     url: this.serverUrl + '/Gy_EquipFileMain/Gy_MouldFileBillBarCodeInfo', 
-						// 	data: { HBarCode: res.result },
-						//     success: (res) => {
-						//         console.log(res.data);
-						// 		var data = res.data.list[0][0]
-						// 		if(res.data.count == 1){
-						// 			this.hform.HEquipID = data.hmainid
-						// 			this.hform.HEquipName = data.璁惧鍚嶇О
-						// 		}
-						// 		uni.showToast({
-						// 			title:res.data.Message,
-						// 			icon:'none'
-						// 		})
-						// 	},
-						// 	fail: (res) => {
-						// 		console.log(res);
-						// 		uni.showToast({
-						// 			title:'鎺ュ彛璇锋眰澶辫触',
-						// 			icon:'none'
-						// 		})
-						// 	},
-						// });
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					this.hform.HBarCode = ret.resp_result
+					// uni.request({
+					//     url: this.serverUrl + '/Gy_EquipFileMain/Gy_MouldFileBillBarCodeInfo', 
+					// 	data: { HBarCode: ret.resp_result },
+					//     success: (res) => {
+					//         console.log(res.data);
+					// 		var data = res.data.list[0][0]
+					// 		if(res.data.count == 1){
+					// 			this.hform.HEquipID = data.hmainid
+					// 			this.hform.HEquipName = data.璁惧鍚嶇О
+					// 		}
+					// 		uni.showToast({
+					// 			title:res.data.Message,
+					// 			icon:'none'
+					// 		})
+					// 	},
+					// 	fail: (res) => {
+					// 		console.log(res);
+					// 		uni.showToast({
+					// 			title:'鎺ュ彛璇锋眰澶辫触',
+					// 			icon:'none'
+					// 		})
+					// 	},
+					// });
+				})
 			},
 			// upCode(){
 			// 	uni.request({
diff --git a/pages/tiaomachaima/tiaomachaima.vue b/pages/tiaomachaima/tiaomachaima.vue
index d816ac8..26007ba 100644
--- a/pages/tiaomachaima/tiaomachaima.vue
+++ b/pages/tiaomachaima/tiaomachaima.vue
@@ -314,39 +314,42 @@
 
 			},
 			toScanCode() {
-				uni.scanCode({
-					onlyFromCamera: true,
-					success: (res) => {
-						if (this.CommonUtils.isEmpty(res.result) === false) {
-							console.log('鏉$爜鍐呭锛�' + res.result);
-							this.barCodeInfoMeta.barCodeNo = res.result
-
-							this.searchbarCodeInfo()
-							// this.doRequest(
-							// 	"/Gy_SplitBarCode/Info", {
-							// 		HBarCodeNo: res.result,
-							// 		HSplitBarNum: 1
-							// 	},
-							// 	function(res) {
-							// 		console.log(res)
-							// 		this.barCodeSplitInfo = []
-							// 		let res1 = res.data
-							// 		let {
-							// 			data,
-							// 			count
-							// 		} = res1
-							// 		if (count > 0) {
-							// 			console.log(data[0])
-							// 			this.barCodeInfo = data[0]
-							// 		}
-							// 	},
-							// 	function(err) {
-							// 		console.error(err)
-							// 	}
-							// )
-						}
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					if (this.CommonUtils.isEmpty(ret.resp_result) === false) {
+						console.log('鏉$爜鍐呭锛�' + ret.resp_result);
+						this.barCodeInfoMeta.barCodeNo = ret.resp_result
+					
+						this.searchbarCodeInfo()
+						// this.doRequest(
+						// 	"/Gy_SplitBarCode/Info", {
+						// 		HBarCodeNo: ret.resp_result,
+						// 		HSplitBarNum: 1
+						// 	},
+						// 	function(res) {
+						// 		console.log(res)
+						// 		this.barCodeSplitInfo = []
+						// 		let res1 = res.data
+						// 		let {
+						// 			data,
+						// 			count
+						// 		} = res1
+						// 		if (count > 0) {
+						// 			console.log(data[0])
+						// 			this.barCodeInfo = data[0]
+						// 		}
+						// 	},
+						// 	function(err) {
+						// 		console.error(err)
+						// 	}
+						// )
 					}
-				});
+				})
 			}
 		},
 		onLoad() {
diff --git a/pages/weiwaigxOut/firstCheck.vue b/pages/weiwaigxOut/firstCheck.vue
index aa227e4..38fcc57 100644
--- a/pages/weiwaigxOut/firstCheck.vue
+++ b/pages/weiwaigxOut/firstCheck.vue
@@ -364,36 +364,38 @@
         methods: {
 			//鎵爜
 			toScanCode(){
-				uni.scanCode({
-				    onlyFromCamera: true,
-				    success: (res) => {
-				        console.log('鏉$爜鍐呭锛�' + res.result);
-						this.hform.HBarCode = res.result
-						// uni.request({
-						//     url: this.serverUrl + '/Gy_EquipFileMain/Gy_MouldFileBillBarCodeInfo', 
-						// 	data: { HBarCode: res.result },
-						//     success: (res) => {
-						//         console.log(res.data);
-						// 		var data = res.data.list[0][0]
-						// 		if(res.data.count == 1){
-						// 			this.hform.HEquipID = data.hmainid
-						// 			this.hform.HEquipName = data.璁惧鍚嶇О
-						// 		}
-						// 		uni.showToast({
-						// 			title:res.data.Message,
-						// 			icon:'none'
-						// 		})
-						// 	},
-						// 	fail: (res) => {
-						// 		console.log(res);
-						// 		uni.showToast({
-						// 			title:'鎺ュ彛璇锋眰澶辫触',
-						// 			icon:'none'
-						// 		})
-						// 	},
-						// });
-				    }
-				});
+				var mpaasScanModule = uni.requireNativePlugin("Mpaas-Scan-Module")
+				mpaasScanModule.mpaasScan({
+					'hideAlbum': true,
+					'timeoutInterval':'10', //瓒呮椂鏃堕棿
+					'timeoutText':'鏈瘑鍒埌浜岀淮鐮�' //瓒呮椂鎻愰啋            
+				},(ret) => {
+					console.log(ret.resp_result)
+					this.hform.HBarCode = ret.resp_result
+					// uni.request({
+					//     url: this.serverUrl + '/Gy_EquipFileMain/Gy_MouldFileBillBarCodeInfo', 
+					// 	data: { HBarCode: ret.resp_result },
+					//     success: (res) => {
+					//         console.log(res.data);
+					// 		var data = res.data.list[0][0]
+					// 		if(res.data.count == 1){
+					// 			this.hform.HEquipID = data.hmainid
+					// 			this.hform.HEquipName = data.璁惧鍚嶇О
+					// 		}
+					// 		uni.showToast({
+					// 			title:res.data.Message,
+					// 			icon:'none'
+					// 		})
+					// 	},
+					// 	fail: (res) => {
+					// 		console.log(res);
+					// 		uni.showToast({
+					// 			title:'鎺ュ彛璇锋眰澶辫触',
+					// 			icon:'none'
+					// 		})
+					// 	},
+					// });
+				})
 			},
 			// upCode(){
 			// 	uni.request({
--
Gitblit v1.9.1